nutrients_pattern_1: with tinyDB priorities: { # # not case sensitive # "names": [ "vitamin d" ], "accepts": [ "vitamin d (d2 + d3)", "vitamin d2", "vitamin d3" ], "unit details": "", "includes equivalents": False } { "code": 2, # # not case sensitive # "names": [ "Niacin" ], "accepts": [], "unit details": "NE", "includes equivalents": True, } { "code": 3, # # not case sensitive # "names": [ "Vitamin C" ], "accepts": [ "vitamin c (form: as calcium ascorbate)", "vitamin c, total ascorbic acid" ], "unit details": "NE", "includes equivalents": False }